#
# GOCAD Script zur Erzeugung von Karten der Schutzfunktion der Grundwasserueberdeckung
#
# Voraussetzungen: HSS_p10z25 (SGRID, Ressourcenmodell), Property: HP (Hoeltingpunkte)
#                  umriss_hss (Curve, GW Leiter Grenze, muss geschlossene Kurve sein, schon auf DHM gesetzt), Property:-
#                  hoehenmodell_hss (Surface, DHM), Property:-
#                  neubildung_hss_points (Points, GW Neubildung, ggf. schon durch 100 geteilt), Property: GRID_CODE (GW Neubildung)
#                  nfk_hss_points (Points, NFK), Property:GRID_CODE (NFK)
#                  gwhoehen_hss (Curve, GW Gleichen, Z schon auf Gleichenwert gesetzt), Property:-
#
# Bearbeitung: Lerch
# Datum: 06.01.2005
#
#----------------------------------------------------------------------------------------------------------------------------------------------
#
# Surface (GWOberflaeche) des Gebietes erstellen
#
gocad tsurf_create_from_gridded_plane name GWOberflaeche p0 3482000 5520000 0. u 250 0. 0. v 0. 250 0. nu 120 nv 148 coordinate_system_name Default_depth 
#
# Um bei DHM Anpassung Problem zu vermeiden Ostrand der Surface um 50m nach Westen verschieben (Region erzeugen und verschienben)
#
gocad on GObj GWOberflaeche range_region region verschieben property X use_min true min 3511950 use_max false max 1. stype or dynamic false
gocad on GObj GWOberflaeche apply_script properties_info None region verschieben script "{ X=X-50; }" check_no_data_values_automatically false file_name None
#
# GWOberflaeche an DHM anpassen
#
gocad edit_push_pull problem GWOberflaeche region everywhere reference hoehenmodell_hss operation "Pull Up" minimum_thickness 0.0 thickness_unit "Z unit" viewing_negative_z_scaling false surgically_move true use_global_dsi false use_regional_dsi false add_extra_nodes false 
gocad edit_push_pull problem GWOberflaeche region everywhere reference hoehenmodell_hss operation "Push Down" minimum_thickness 0.0 thickness_unit "Z unit" viewing_negative_z_scaling false surgically_move true use_global_dsi false use_regional_dsi false add_extra_nodes false 
#
# Ostrand zurckverschieben (und Region lschen)
#
gocad on GObj GWOberflaeche apply_script properties_info None region verschieben script "{ X=X+50; }" check_no_data_values_automatically false file_name None
gocad on GObj GWOberflaeche delete_region region verschieben
#
# Aus Curve GW Gleichen Pointset gwhoehen_points machen
#
gocad vset_create_from_points name gwhoehen_points points gwhoehen_hss region everywhere copy_properties false dissociate_vertices true merge_parts true
#
# Pointset gwhoehen_points und curve umriss_hss zu Surface gwhoehen_surface machen
#
gocad tsurf_create_from_points_and_curve name gwhoehen_surface curve umriss_hss points gwhoehen_points densification_type "homogeneous triangles" densification_factor 1.0 use_normal true normal 0. 0. 1. dissociate_vertices true copy_properties false 
#
# GWOberflche an gwhoehen_surface anpassen (push down)
#
gocad edit_push_pull problem GWOberflaeche region everywhere reference gwhoehen_surface operation "Push Down" minimum_thickness 0.0 thickness_unit "Z unit" viewing_negative_z_scaling false surgically_move true use_global_dsi false use_regional_dsi false add_extra_nodes false 
#
# Von GWOberflaeche Z in SGRID Property GWS (Grundwasserstand) uebertragen (mit vertical projection)
#
gocad on VerticalPropertyClient HSS_p10z25 fill_vertically_from_property region everywhere new_property_name GWS from GWOberflaeche from_region everywhere property Z share_property_class false 
gocad on GridObj HSS_p10z25 storage_swap  properties GWS storage "disk" memory_usage 45 brick_size_nu 16 brick_size_nv 16 brick_size_nw 128
#
# Aus NFK Punkten NFK Surface erstellen 
#
gocad tsurf_create_from_points name NFK_surface points nfk_hss_points use_normal false normal 0. 0. 1. dissociate_vertices true copy_properties true 
#
# Aus NFK_surface Property GRID_CODE in SGRID Property B uebertragen (mit "vertical projection")
#
gocad on VerticalPropertyClient HSS_p10z25 fill_vertically_from_property region everywhere new_property_name B from NFK_surface from_region everywhere property GRID_CODE share_property_class false 
gocad on GridObj HSS_p10z25 storage_swap  properties B storage "disk" memory_usage 45 brick_size_nu 16 brick_size_nv 16 brick_size_nw 128
#
# Aus GW Neubildung Punkten GWN Surface erstellen 
#
gocad tsurf_create_from_points name GWN_surface points neubildung_hss_points use_normal false normal 0. 0. 1. dissociate_vertices true copy_properties true 
#
# Aus GWN_surface Property GRID_CODE in SGRID Property WA uebertragen (mit "vertical projection")
#
gocad on VerticalPropertyClient HSS_p10z25 fill_vertically_from_property region everywhere new_property_name WA from GWN_surface from_region everywhere property GRID_CODE share_property_class false 
gocad on GridObj HSS_p10z25 storage_swap  properties WA storage "disk" memory_usage 45 brick_size_nu 16 brick_size_nv 16 brick_size_nw 128
#
# Hoehe jeder Zelle berechnen und in thick schreiben
#
gocad on SGrid HSS_p10z25 sgrid_compute_cells_thicknesses Along_I false property_name_I DX Along_J false property_name_J DY Along_K true property_name_K thick True_DZ false
gocad on GridObj HSS_p10z25 storage_swap  properties thick storage "disk" memory_usage 45 brick_size_nu 16 brick_size_nv 16 brick_size_nw 128
#
# Mit der sum Funktion die Unterkante jeder Schicht in UK schreiben
#
gocad on GridObj HSS_p10z25 sum_property property_name thick new_property_name UK specify_new_property_class false new_property_class _x_tsurf_stoerungen axis W direction reverse region_name everywhere extend_result false restart_at_discontinuity true
gocad on GridObj HSS_p10z25 storage_swap  properties UK storage "disk" memory_usage 45 brick_size_nu 16 brick_size_nv 16 brick_size_nw 128
#
# In SGRID Property UZ (Anzeiger fr ungesttigte Zomne) erzeugen, auf 0 setzen und wenn (Z>=GWS) auf 1 setzen
#
gocad on GObj HSS_p10z25 create_property  property_name UZ no_datavalue_specified 1 no_datavalue -99999 number_of_elements 1 property_kind unknown storage Memory
gocad on GridObj HSS_p10z25 storage_swap  properties UZ storage "disk" memory_usage 45 brick_size_nu 16 brick_size_nv 16 brick_size_nw 128
gocad on GObj HSS_p10z25 apply_script properties_info None region everywhere script "{ UZ=0; }" check_no_data_values_automatically false file_name None
gocad on GObj HSS_p10z25 apply_script properties_info None region everywhere script "{ if (Z>=GWS){UZ=1;} }" check_no_data_values_automatically false file_name None
#
# In SGRID HP in G umbenennen
#
gocad on GObj HSS_p10z25 rename_property old_name HP new_name G 
#
# in SGRID G auf 0 setzen, wenn G<0
#
gocad on GObj HSS_p10z25 apply_script properties_info None region everywhere script "{ if(G<0){G=0;} }" check_no_data_values_automatically false file_name None
#
# In SGRID Property ZO (Zuschlag Organik) erzeugen, auf 0 setzen und bei OG>8 auf 1 setzen
#
gocad on GObj HSS_p10z25 create_property  property_name ZO no_datavalue_specified 1 no_datavalue -99999 number_of_elements 1 property_kind unknown storage Memory
gocad on GridObj HSS_p10z25 storage_swap  properties ZO storage "disk" memory_usage 45 brick_size_nu 16 brick_size_nv 16 brick_size_nw 128
gocad on GObj HSS_p10z25 apply_script properties_info None region everywhere script "{ ZO=0; }" check_no_data_values_automatically false file_name None
gocad on GObj HSS_p10z25 apply_script properties_info None region everywhere script "{ if (OG>8){ZO=1;} }" check_no_data_values_automatically false file_name None
#
# IN SGRID Property SF erzeugen und auf 0 setzen
#
gocad on GObj HSS_p10z25 create_property  property_name SF no_datavalue_specified 1 no_datavalue -99999 number_of_elements 1 property_kind unknown storage Memory
gocad on GridObj HSS_p10z25 storage_swap  properties SF storage "disk" memory_usage 45 brick_size_nu 16 brick_size_nv 16 brick_size_nw 128
gocad on GObj HSS_p10z25 apply_script properties_info None region everywhere script "{ SF=0; }" check_no_data_values_automatically false file_name None
#
# SF berechnen
#
gocad on GObj HSS_p10z25 apply_script properties_info None region everywhere script "{ if (UK <= 1) { SF = B*WA*thick*UZ ; } else { SF = ((G*WA*thick)+(ZO*75*thick))*UZ ; } }" check_no_data_values_automatically false file_name None
#
# Wenn SF<0 SF auf 0 setzen
#
gocad on GObj HSS_p10z25 apply_script properties_info None region everywhere script "{ if (SF<0){SF=1;} }" check_no_data_values_automatically false file_name None
#
# In SGRID SF in SP aufsummieren
#
gocad on GridObj HSS_p10z25 sum_property property_name SF new_property_name SP specify_new_property_class false new_property_class _x_tsurf_stoerungen axis W direction normal region_name everywhere extend_result false restart_at_discontinuity true
gocad on GridObj HSS_p10z25 storage_swap  properties SP storage "disk" memory_usage 45 brick_size_nu 16 brick_size_nv 16 brick_size_nw 128
#
# Oberstes Layer des SGRIDs in Pointset exportieren
#
gocad create_vset_from_sgrid_section name schutzfunktion_points the_sgrid HSS_p10z25 axis W index 1345 copy_property true property SP
#
# Z in Pointset auf SP setzen (zum exportieren)
#
gocad on GObj schutzfunktion_points apply_script properties_info None region everywhere script "{ Z=SP;}" check_no_data_values_automatically false file_name None
#
# In dxf exportieren
#
gocad export_dxf_file objects schutzfunktion_points File_name /usr/people/lerch/gocad/exchange/schutzfunktion/schutzf_p10z25.dxf
